@@ -15,6 +15,6 @@
 
 from tooz import coordination
 
-coordinator = coordination.get_coordinator('zake://', b'host-1')
+coordinator = coordination.get_coordinator('redis://localhost:6379', b'host-1')
 coordinator.start(start_heart=True)
 coordinator.stop()
